pyselenscrapr package
=====================

Submodules
----------

pyselenscrapr.ScrapingBackend module
------------------------------------

.. automodule:: pyselenscrapr.ScrapingBackend
   :members:
   :undoc-members:
   :show-inheritance:

pyselenscrapr.ScrapingBot module
--------------------------------

.. automodule:: pyselenscrapr.ScrapingBot
   :members:
   :undoc-members:
   :show-inheritance:

pyselenscrapr.ScrapingLogic module
----------------------------------

.. automodule:: pyselenscrapr.ScrapingLogic
   :members:
   :undoc-members:
   :show-inheritance:

pyselenscrapr.ScrapingStep module
---------------------------------

.. automodule:: pyselenscrapr.ScrapingStep
   :members:
   :undoc-members:
   :show-inheritance:

pyselenscrapr.ScrapingStepGroup module
--------------------------------------

.. automodule:: pyselenscrapr.ScrapingStepGroup
   :members:
   :undoc-members:
   :show-inheritance:

pyselenscrapr.ScrapingStepLoop module
-------------------------------------

.. automodule:: pyselenscrapr.ScrapingStepLoop
   :members:
   :undoc-members:
   :show-inheritance:

pyselenscrapr.ScrapingStepPagination module
-------------------------------------------

.. automodule:: pyselenscrapr.ScrapingStepPagination
   :members:
   :undoc-members:
   :show-inheritance:

pyselenscrapr.ValidationError module
------------------------------------

.. automodule:: pyselenscrapr.ValidationError
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyselenscrapr
   :members:
   :undoc-members:
   :show-inheritance:
